@@ -4,16 +4,8 @@ import os
 from contextlib import contextmanager
 from functools import partial
 from unittest import TestCase
-
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch
-
-try:
-    from urllib.parse import urlparse, parse_qs
-except ImportError:
-    from urlparse import urlparse, parse_qs
+from unittest.mock import patch
+from urllib.parse import parse_qs, urlparse
 
 from cs import (
     CloudStack,
@@ -154,7 +146,6 @@ class ConfigTest(TestCase):
                     "trace": None,
                     "poll_interval": 2.0,
                     "name": "hanibal",
-                    "poll_interval": 2.0,
                     "verify": None,
                     "dangerous_no_tls_verify": True,
                     "retry": 0,
@@ -194,7 +185,6 @@ class ConfigTest(TestCase):
                     "trace": None,
                     "poll_interval": 2.0,
                     "name": "cloudstack",
-                    "poll_interval": 2.0,
                     "verify": None,
                     "dangerous_no_tls_verify": True,
                     "retry": 0,
